@@ -7,3 +7,6 @@ EXIT_STATUS_FAIL_UNUSED = 1
 SYMBOL_ELLIPSIS = "..."  # U+2026
 SYMBOL_NEW_LINE = "␤"  # U+2424
 SYMBOL_CARRIAGE = "␍"  # U+240D
+
+DISABLE_COLOR_ENV_VAR = "ANSI_COLORS_DISABLED"
+DISABLE_COLOR_ENV_VARS = {DISABLE_COLOR_ENV_VAR, "NO_COLOR"}
