@@ -43,15 +43,25 @@ from syrupy.terminal import (
 )
 from syrupy.utils import walk_snapshot_dir
 
-
 if TYPE_CHECKING:
     from syrupy.location import TestLocation
-    from syrupy.types import SerializableData, SerializedData
+    from syrupy.types import (
+        PropertyFilter,
+        PropertyMatcher,
+        SerializableData,
+        SerializedData,
+    )
 
 
 class SnapshotSerializer(ABC):
     @abstractmethod
-    def serialize(self, data: "SerializableData") -> "SerializedData":
+    def serialize(
+        self,
+        data: "SerializableData",
+        *,
+        exclude: Optional["PropertyFilter"] = None,
+        matcher: Optional["PropertyMatcher"] = None,
+    ) -> "SerializedData":
         """
         Serializes a python object / data structure into a string
         to be used for comparison with snapshot data from disk.
@@ -336,8 +346,8 @@ class SnapshotReporter(ABC):
         num_lines = len(lines)
         if num_lines:
             if num_lines > self._context_line_max:
-                count_leading_whitespace: Callable[[str], int] = (
-                    lambda s: len(s) - len(s.lstrip())  # noqa: E731
+                count_leading_whitespace: Callable[[str], int] = lambda s: len(s) - len(
+                    s.lstrip()
                 )
                 if self._context_line_count:
                     num_space = (
