@@ -5,13 +5,13 @@ from gettext import (
 from pathlib import Path
 from typing import (
     TYPE_CHECKING,
-    Any,
+    Dict,
     Iterator,
     List,
-    Set,
 )
 
 import attr
+import pytest
 
 from .data import (
     Snapshot,
@@ -28,16 +28,15 @@ from .terminal import (
     warning_style,
 )
 
-
 if TYPE_CHECKING:
-    from .assertion import SnapshotAssertion  # noqa: F401
+    from .assertion import SnapshotAssertion
 
 
 @attr.s
 class SnapshotReport:
     base_dir: str = attr.ib()
-    all_items: Set[Any] = attr.ib()
-    ran_items: Set[Any] = attr.ib()
+    all_items: Dict["pytest.Item", bool] = attr.ib()
+    ran_items: Dict["pytest.Item", bool] = attr.ib()
     update_snapshots: bool = attr.ib()
     is_providing_paths: bool = attr.ib()
     is_providing_nodes: bool = attr.ib()
@@ -136,13 +135,17 @@ class SnapshotReport:
         if self.num_failed:
             summary_lines.append(
                 ngettext(
-                    "{} snapshot failed.", "{} snapshots failed.", self.num_failed,
+                    "{} snapshot failed.",
+                    "{} snapshots failed.",
+                    self.num_failed,
                 ).format(error_style(self.num_failed))
             )
         if self.num_matched:
             summary_lines.append(
                 ngettext(
-                    "{} snapshot passed.", "{} snapshots passed.", self.num_matched,
+                    "{} snapshot passed.",
+                    "{} snapshots passed.",
+                    self.num_matched,
                 ).format(success_style(self.num_matched))
             )
         if self.num_created:
@@ -156,7 +159,9 @@ class SnapshotReport:
         if self.num_updated:
             summary_lines.append(
                 ngettext(
-                    "{} snapshot updated.", "{} snapshots updated.", self.num_updated,
+                    "{} snapshot updated.",
+                    "{} snapshots updated.",
+                    self.num_updated,
                 ).format(green(self.num_updated))
             )
         if self.num_unused:
