@@ -1,7 +1,11 @@
+import uuid
 from collections import namedtuple
+from datetime import datetime
 
 import pytest
 
+from syrupy.extensions.amber.serializer import Repr
+
 
 def test_non_snapshots(snapshot):
     with pytest.raises(AssertionError):
@@ -23,6 +27,17 @@ def test_newline_control_characters(snapshot):
     assert snapshot == "line 1\r\nline 2\r\n"
 
 
+def test_multiline_string_in_dict(snapshot):
+    lines = "\n".join(["line 1", "line 2"])
+    assert {"value": lines} == snapshot
+
+
+def test_deeply_nested_multiline_string_in_dict(snapshot):
+    lines = "\n".join(["line 1", "line 2", "line 3"])
+    d = {"value_a": {"value_b": lines}}
+    assert d == snapshot
+
+
 @pytest.mark.parametrize("actual", [False, True])
 def test_bool(actual, snapshot):
     assert actual == snapshot
@@ -61,6 +76,7 @@ ExampleTuple = namedtuple("ExampleTuple", ["a", "b", "c", "d"])
 def test_tuple(snapshot):
     assert snapshot == ("this", "is", ("a", "tuple"))
     assert snapshot == ExampleTuple(a="this", b="is", c="a", d={"named", "tuple"})
+    assert snapshot == ()
 
 
 @pytest.mark.parametrize(
@@ -70,6 +86,7 @@ def test_tuple(snapshot):
         {"contains", "frozen", frozenset({"1", "2"})},
         {"contains", "tuple", (1, 2)},
         {"contains", "namedtuple", ExampleTuple(a=1, b=2, c=3, d=4)},
+        set(),
     ],
 )
 def test_set(snapshot, actual):
@@ -87,6 +104,10 @@ def test_set(snapshot, actual):
             frozenset({"1", "2"}): ["1", 2],
             ExampleTuple(a=1, b=2, c=3, d=4): {"e": False},
         },
+        {},
+        {"key": ["line1\nline2"]},
+        {"key": [1, "line1\nline2", 2, "line3\nline4"]},
+        {"key": [1, ["line1\nline2"], 2]},
     ],
 )
 def test_dict(snapshot, actual):
@@ -99,8 +120,17 @@ def test_numbers(snapshot):
     assert snapshot == 2 / 6
 
 
-def test_list(snapshot):
-    assert snapshot == [1, 2, "string", {"key": "value"}]
+@pytest.mark.parametrize(
+    "actual",
+    [
+        [],
+        ["this", "is", "a", "list"],
+        ["contains", "empty", []],
+        [1, 2, "string", {"key": "value"}],
+    ],
+)
+def test_list(snapshot, actual):
+    assert actual == snapshot
 
 
 list_cycle = [1, 2, 3]
@@ -154,3 +184,44 @@ class TestClass:
     class TestNestedClass:
         def test_nested_class_method(self, snapshot, actual):
             assert snapshot == f"parameterized nested class method {actual}"
+
+
+class TestSubClass(TestClass):
+    pass
+
+
+@pytest.mark.parametrize("parameter_with_dot", ("value.with.dot",))
+def test_parameter_with_dot(parameter_with_dot, snapshot):
+    assert parameter_with_dot == snapshot
+
+
+@pytest.mark.parametrize("parameter_1", ("foo",))
+@pytest.mark.parametrize("parameter_2", ("bar",))
+def test_doubly_parametrized(parameter_1, parameter_2, snapshot):
+    assert parameter_1 == snapshot
+    assert parameter_2 == snapshot
+
+
+def test_non_deterministic_snapshots(snapshot):
+    def matcher(data, path):
+        if isinstance(data, uuid.UUID):
+            return Repr("UUID(...)")
+        if isinstance(data, datetime):
+            return Repr("datetime.datetime(...)")
+        if tuple(p for p, _ in path[-2:]) == ("c", 0):
+            return "Your wish is my command"
+        return data
+
+    assert {
+        "a": uuid.uuid4(),
+        "b": {"b_1": "This is deterministic", "b_2": datetime.now()},
+        "c": ["Replace this one", "Do not replace this one"],
+    } == snapshot(matcher=matcher)
+    assert {
+        "a": uuid.UUID("06335e84-2872-4914-8c5d-3ed07d2a2f16"),
+        "b": {
+            "b_1": "This is deterministic",
+            "b_2": datetime(year=2020, month=5, day=31),
+        },
+        "c": ["Replace this one", "Do not replace this one"],
+    } == snapshot
