@@ -1,7 +1,5 @@
 import pytest
 
-from .utils import clean_output
-
 
 @pytest.fixture
 def testcases(testdir):
@@ -67,7 +65,7 @@ def testcases_updated(testcases):
 def test_unsaved_snapshots(snapshot, testdir, testcases):
     testdir.makepyfile(test_file=testcases["passed"])
     result = testdir.runpytest("-v")
-    output = clean_output(result.stdout.str())
+    output = result.stdout.str()
     assert "Snapshot does not exist" in output
     assert "+ b'passed1'" in output
     assert result.ret == 1
@@ -76,7 +74,7 @@ def test_unsaved_snapshots(snapshot, testdir, testcases):
 def test_failed_snapshots(testdir, testcases):
     testdir.makepyfile(test_file=testcases["failed"])
     result = testdir.runpytest("-v", "--snapshot-update")
-    assert "2 snapshots failed" in clean_output(result.stdout.str())
+    assert "2 snapshots failed" in result.stdout.str()
     assert result.ret == 1
 
 
@@ -88,7 +86,7 @@ def stubs(testdir, testcases):
 
 def test_generated_snapshots(stubs):
     result = stubs[0]
-    result_stdout = clean_output(result.stdout.str())
+    result_stdout = result.stdout.str()
     assert "2 snapshots generated" in result_stdout
     assert "snapshots unused" not in result_stdout
     assert result.ret == 0
@@ -98,7 +96,7 @@ def test_unmatched_snapshots(stubs, testcases_updated):
     testdir = stubs[1]
     testdir.makepyfile(test_file=testcases_updated["passed"])
     result = testdir.runpytest("-v")
-    result_stdout = clean_output(result.stdout.str())
+    result_stdout = result.stdout.str()
     assert "1 snapshot failed" in result_stdout
     assert "1 snapshot unused" in result_stdout
     assert result.ret == 1
@@ -108,7 +106,7 @@ def test_updated_snapshots(stubs, testcases_updated):
     testdir = stubs[1]
     testdir.makepyfile(test_file=testcases_updated["passed"])
     result = testdir.runpytest("-v", "--snapshot-update")
-    result_stdout = clean_output(result.stdout.str())
+    result_stdout = result.stdout.str()
     assert "1 snapshot updated" in result_stdout
     assert "1 unused snapshot deleted" in result_stdout
     assert result.ret == 0
